local name, private = ...

Excavatinator = private.objects.base()

Excavatinator:RegisterEvent("ADDON_LOADED")

Excavatinator.isLoaded = false
Excavatinator.questList = {}
RequestArtifactCompletionHistory()

function Excavatinator:ADDON_LOADED(addon)
    if addon ~= name then return end
    private.artifacts:process()
    self:VerifyDB()
    self:UPDATE_BINDINGS()
end

function Excavatinator:PLAYER_LOGOUT()
    self:SaveDB()
end

function Excavatinator:VerifyDB()
    -- Check that the saved data variable is a table; if not, overwrite it with a table
    if type(ExcavatinatorDB) ~= "table" then
        ExcavatinatorDB = {}
    end
    
    -- Do the same for linkedProjects
    if type(ExcavatinatorDB.linkedProjects) ~= "table" then
        ExcavatinatorDB.linkedProjects = {}
    end
    
    -- Do the same for framePosition
    if type(ExcavatinatorDB.framePosition) ~= "table" then
        ExcavatinatorDB.framePosition = { "CENTER", 0, 0, false }
    end
end

function Excavatinator:LoadDB()
    -- Load links
    for projectName, itemName in pairs(ExcavatinatorDB.linkedProjects) do
        private.links:addLink(itemName, projectName)
    end
end

function Excavatinator:SaveDB()
    if not self.isLoaded then return end
    
    -- Save links
    ExcavatinatorDB.linkedProjects = private.links.byProject -- The old addon kept links in this order. No good reason to change.
    
    -- Save frame position
    local point, _, _, x, y = self.raceFrame.frame:GetPoint()
    if not (point == "CENTER" and x == 0 and y == 0) then -- Somehow, the frame seems to reset to the center sometimes. No idea why.
        ExcavatinatorDB.framePosition = { point, x, y, self.raceFrame.isCollapsed }
    end
end

function Excavatinator:Load()
    -- Verify the saved data
    self:VerifyDB()
    
    -- Load saved data
    self:LoadDB()
    
    private.achievements:process()
    private.artifacts:process()
    self.raceFrame = private.objects.ui.raceFrame()
    self.raceFrame:init()
    self.raceFrame.frame:SetPoint(unpack(ExcavatinatorDB.framePosition))
    if ExcavatinatorDB.framePosition[4] then
        self.raceFrame:ShowContinent()
    end
    
    self:RegisterEvent("PLAYER_LOGOUT")
    
    self.isLoaded = true
end

function showExcavatinator() -- This is the slash command, so it can't have a self reference
    if InCombatLockdown() then
        print("You are in combat! Excavatinator cannot open.")
        return nil
    end
    if Excavatinator.isLoaded then
        if Excavatinator.raceFrame:IsShown() then
            Excavatinator.raceFrame:Hide()
        else
            Excavatinator.raceFrame:Show()
        end
    else
        Excavatinator:Load()
        RequestArtifactCompletionHistory() -- Not sure if it took the first time; it did seem to have issues.
    end
end

SLASH_EXCAVATINATOR1 = '/arch'
SlashCmdList["EXCAVATINATOR"] = showExcavatinator

-- Survey key binding code
-- Why all this? Binding keys using pure Lua leaves it up to the programmer to select
-- the key to bind, not the user. Binding keys using pure XML makes the user select,
-- but only lets the programmer select the spell to bind by name, which doesn't work
-- for multiple languages.
-- This workaround uses binding overrides - the binding for "Cast Survey" doesn't
-- actually do anything, but when the game loads or the key binding settings change,
-- this code finds out which key it was bound to and creates an override. It still
-- has to pass in the spell name, but since it happens in Lua this time, the code can
-- get the spell name programmatically.
Excavatinator:RegisterEvent("UPDATE_BINDINGS")
function Excavatinator:UPDATE_BINDINGS()
    local binding = GetNumBindings();
    while GetBinding(binding) ~= "EXCAVATINATOR_SURVEY" do binding = binding - 1 end
    
    local _, _, key1, key2 = GetBinding(binding)
    ClearOverrideBindings(Excavatinator.__eventFrame)
    local survey_name = GetSpellInfo(80451)
    if (key1) then
        SetOverrideBindingSpell(Excavatinator.__eventFrame, true, key1, survey_name)
    end
    if (key2) then
        SetOverrideBindingSpell(Excavatinator.__eventFrame, true, key2, survey_name)
    end
end

-- Cache the data for Survey
GetSpellInfo(80451)